==> ij-segment-wrapper-1.13.0.tgz: package/lib/infojobsVisitor/AdobeRepository.js <==
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
var TIME_BETWEEN_RETRIES = 250;
var TIMES_TO_RETRY = 80;
var ADOBE_ORG_ID = '05FF6243578784B37F000101@AdobeOrg';
var ADOBE_SERVERS = {
  trackingServer: 'schibstedspain.d3.sc.omtrdc.net',
  trackingServerSecure: 'schibstedspain.d3.sc.omtrdc.net'
};

var _visitorId = /*#__PURE__*/_classPrivateFieldLooseKey("visitorId");

var _getMarketingCloudVisitorID = /*#__PURE__*/_classPrivateFieldLooseKey("getMarketingCloudVisitorID");

export var AdobeMarketingCloudVisitorIdRepository = /*#__PURE__*/function () {
  function AdobeMarketingCloudVisitorIdRepository() {
    Object.defineProperty(this, _getMarketingCloudVisitorID, {
      value: _getMarketingCloudVisitorID2
    });
    Object.defineProperty(this, _visitorId, {
      writable: true,
      value: ''
    });
  }

  var _proto = AdobeMarketingCloudVisitorIdRepository.prototype;

  _proto.get = function get() {
    var _this = this;

    return new Promise(function (resolve) {
      var retry = function retry(retries) {
        if (retries === 0) return resolve('');
        _classPrivateFieldLooseBase(_this, _visitorId)[_visitorId] = _classPrivateFieldLooseBase(_this, _getMarketingCloudVisitorID)[_getMarketingCloudVisitorID]();
        return _classPrivateFieldLooseBase(_this, _visitorId)[_visitorId] !== undefined ? resolve(_classPrivateFieldLooseBase(_this, _visitorId)[_visitorId]) : window.setTimeout(function () {
          return retry(--retries);
        }, TIME_BETWEEN_RETRIES);
      };

      retry(TIMES_TO_RETRY);
    });
  };

  return AdobeMarketingCloudVisitorIdRepository;
}();

function _getMarketingCloudVisitorID2() {
  var mcvid;

  try {
    var demdex = window.Visitor.getInstance(ADOBE_ORG_ID, ADOBE_SERVERS);
    mcvid = demdex.getMarketingCloudVisitorID();
  } catch (error) {
    mcvid = '';
  }

  return mcvid;
}

==> ij-segment-wrapper-2.1.0.tgz: package/lib/infojobsVisitor/AdobeRepository.js <==
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
var TIME_BETWEEN_RETRIES = 250;
var TIMES_TO_RETRY = process.env.NODE_ENV === 'test' ? 1 : 80;
var ADOBE_ORG_ID = '05FF6243578784B37F000101@AdobeOrg';
var ADOBE_SERVERS = {
  trackingServer: 'schibstedspain.d3.sc.omtrdc.net',
  trackingServerSecure: 'schibstedspain.d3.sc.omtrdc.net'
};

var _visitorId = /*#__PURE__*/_classPrivateFieldLooseKey("visitorId");

var _getMarketingCloudVisitorID = /*#__PURE__*/_classPrivateFieldLooseKey("getMarketingCloudVisitorID");

export var AdobeMarketingCloudVisitorIdRepository = /*#__PURE__*/function () {
  function AdobeMarketingCloudVisitorIdRepository() {
    Object.defineProperty(this, _getMarketingCloudVisitorID, {
      value: _getMarketingCloudVisitorID2
    });
    Object.defineProperty(this, _visitorId, {
      writable: true,
      value: ''
    });
  }

  var _proto = AdobeMarketingCloudVisitorIdRepository.prototype;

  _proto.get = function get() {
    var _this = this;

    return new Promise(function (resolve) {
      var retry = function retry(retries) {
        if (retries === 0) return resolve('');
        _classPrivateFieldLooseBase(_this, _visitorId)[_visitorId] = _classPrivateFieldLooseBase(_this, _getMarketingCloudVisitorID)[_getMarketingCloudVisitorID]();
        return _classPrivateFieldLooseBase(_this, _visitorId)[_visitorId] ? resolve(_classPrivateFieldLooseBase(_this, _visitorId)[_visitorId]) : window.setTimeout(function () {
          return retry(--retries);
        }, TIME_BETWEEN_RETRIES);
      };

      retry(TIMES_TO_RETRY);
    });
  };

  return AdobeMarketingCloudVisitorIdRepository;
}();

function _getMarketingCloudVisitorID2() {
  var mcvid;

  try {
    var demdex = window.Visitor.getInstance(ADOBE_ORG_ID, ADOBE_SERVERS);
    mcvid = demdex.getMarketingCloudVisitorID();
  } catch (error) {}

  return mcvid;
}
